##' @title Graphs and Network Optimization algorithms
##'
##' @description This is a hardly complete collection of algorithms
##'     from the subject "Graphs and Network Optimization".
##'
##' @details Functions in this package have been written for teaching
##'     purposes.  Therefore, no attempt at production versions of the
##'     algorithms has been made.  They are neither complete nor
##'     completely correct, although a great effort has been invested
##'     in their construction and debugging.  All of them pass a
##'     series of tests given in the examples sections of the
##'     corresponding help pages.  Comments and suggestions are
##'     welcome, even if I cannot guarantee that they will be
##'     incorporated to the package.
##'
##' This package makes extensive use of the [igraph::igraph] package
##'     functions, which should be loaded before using "gor".
##'
##' Some functions in this package perform tasks which can be found in
##'     other well-tested packages such as [igraph::igraph] or
##'     [TSP::TSP].  As said before, these functions have been written
##'     with teaching in mind, and I do not claim that "gor" functions
##'     are better than any other in any way whatsoever.
##'
##' @import igraph
##' @author Cesar Asensio (2021-2025)
##' @md
##' @encoding UTF-8
##' @docType package
##' @name gor
##' @keywords internal
"_PACKAGE"
NULL
#> NULL
